add_object_pos_airmass — MSUMastro toolbox 0.1 documentation

# add_object_pos_airmass

`msumastro.header_processing.patchers.` `add_object_pos_airmass`(header, history=False)

  Add object information, such as RA/Dec and airmass.

  Parameters: | header : astropy..io.fits.Header FITS header to be modified. history : bool If True, write history for each keyword changed.

  Notes

  Has side effect of setting feder site JD to JD-OBS, which means it also assume JD.value has been set.